eprllib.RewardFunctions.RewardFunctions — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# eprllib.RewardFunctions.RewardFunctions

## Reward Funtion

This module contains the base reward function.

It has been preferred to use the infos dictionary and not the observation, since the latter is a numpy array and cannot be called by key values, which is prone to errors when developing the program and indexing a arrangement may change.

Classes

`RewardFunction`(reward_fn_config) | This class is the base class for the reward function.